from flask import Flask
from nagext import NagExt
from nagifo import port, cmdfile, verify_hash
from base64 import urlsafe_b64decode as b64dec
app = Flask(__name__)
app.debug = True

ngext = NagExt(cmdfile)

@app.route('/<data>')
def root(data):
    ddata = b64dec(str(data))
    sechash, user, host, desc = ddata.split('/')
    if verify_hash(sechash, user, host, desc):
        ngext.acknowledge_svc_problem(host, desc, 0, 1, 0, user,
                                  'acknowledgement sent from phone')


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=port)




from setuptools import setup, find_packages
import sys, os

version = '0.1.3'

setup(name='nagifo',
      version=version,
      description="Nagios notifications through notifo",
      long_description="""\
Nagios notifications through notifo, plus a small webapp to acknowledge the alert""",
      classifiers=[], # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
      keywords='notifo flask nagios nagifo',
      author='Dominic LoBue',
      author_email='dominic.lobue@gmail.com',
      url='',
      license='GPLv3',
      packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
      include_package_data=True,
      data_files=[
          ('config', ['nagifo.wsgi', 'nagifo.conf']),
      ],
      scripts = ['bin/nagifo'],
      zip_safe=False,
      install_requires=[
          # -*- Extra requirements: -*-
          'notifo',
          'flask',
          'python-nagext',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



from base64 import urlsafe_b64encode as b64enc
from hashlib import sha1
from  notifo import Notifo
import hmac
import socket
import fcntl
import struct

from ConfigParser import SafeConfigParser

config = SafeConfigParser()
config.read('/etc/nagifo.conf')

hostname = config.get('default', 'external_hostname')
port = config.getint('default', 'port')
cmdfile = config.get('default', 'nagios_cmdfile')
secret_key = config.get('default', 'secret_key')


def get_ip_address(ifname):
    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    return socket.inet_ntoa(fcntl.ioctl(
        s.fileno(),
        0x8915,  # SIOCGIFADDR
        struct.pack('256s', ifname[:15])
    )[20:24])


def generate_hash(user, host, desc):
    myip = get_ip_address('eth0')
    return hmac.new(secret_key,
                    ''.join([user, host, desc, myip]), sha1).digest()


def verify_hash(sechash, user, host, desc):
    return sechash == generate_hash(user, host, desc)


def notifo_notify(user, key, ntype, host, state, service_desc, rest):
    title = '%s %s' % (ntype, host)
    msg = '%s - %s, %s' % (state, service_desc, rest)
    
    sechash = generate_hash(user, host, service_desc)
    
    ackurl = 'http://%s/%s' % (hostname, b64enc('/'.join([sechash, user, host,
                                                          service_desc])))
    
    nt = Notifo(user, key)
    nt.send_notification(msg=msg, label='nagios', title=title, uri=ackurl)

